==> skrooge-0.2.5.tar.gz: skrooge-0.2.5/skgbasegui/skgtreeviewdesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * A tree view for skrooge (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgtreeviewdesignerplugin.h"
#include "skgtreeview.h"

#include "kicon.h"

#include <QtPlugin>

SKGTreeViewDesignerPlugin::SKGTreeViewDesignerPlugin(QObject *parent)
                : QObject(parent)
{
        initialized = false;
}

void SKGTreeViewDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
{
        if (initialized) return;

        initialized = true;
}

bool SKGTreeViewDesignerPlugin::isInitialized() const
{
        return initialized;
}

QWidget *SKGTreeViewDesignerPlugin::createWidget(QWidget *parent)
{
        return new SKGTreeView(parent);
}

QString SKGTreeViewDesignerPlugin::name() const
{
        return "SKGTreeView";
}

QString SKGTreeViewDesignerPlugin::group() const
{
        return "SKG Widgets";
}

QIcon SKGTreeViewDesignerPlugin::icon() const
{
        return KIcon("skrooge.png");
}

QString SKGTreeViewDesignerPlugin::toolTip() const
{
        return "A tree view used by skrooge";
}

QString SKGTreeViewDesignerPlugin::whatsThis() const
{
        return "A tree view used by skrooge";
}

bool SKGTreeViewDesignerPlugin::isContainer() const
{
        return true;
}

QString SKGTreeViewDesignerPlugin::domXml() const
{
        return "<widget class=\"SKGTreeView\" name=\"SKGTreeView\">\n"
               " <property name=\"geometry\">\n"
               "  <rect>\n"
               "   <x>0</x>\n"
               "   <y>0</y>\n"
               "   <width>100</width>\n"
               "   <height>100</height>\n"
               "  </rect>\n"
               " </property>\n"
               "</widget>\n";
}

QString SKGTreeViewDesignerPlugin::includeFile() const
{
        return "skgtreeview.h";
}

==> skrooge_0.6.0.orig.tar.gz: skrooge-0.6.0/skgbasegui/skgtreeviewdesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * A tree view with more features (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgtreeviewdesignerplugin.h"
#include "skgtreeview.h"

#include "kicon.h"

#include <QtPlugin>

SKGTreeViewDesignerPlugin::SKGTreeViewDesignerPlugin(QObject *parent)
                : QObject(parent)
{
        initialized = false;
}

void SKGTreeViewDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
{
        if (initialized) return;

        initialized = true;
}

bool SKGTreeViewDesignerPlugin::isInitialized() const
{
        return initialized;
}

QWidget *SKGTreeViewDesignerPlugin::createWidget(QWidget *parent)
{
        return new SKGTreeView(parent);
}

QString SKGTreeViewDesignerPlugin::name() const
{
        return "SKGTreeView";
}

QString SKGTreeViewDesignerPlugin::group() const
{
        return "SKG Widgets";
}

QIcon SKGTreeViewDesignerPlugin::icon() const
{
        return KIcon("skg_open");
}

QString SKGTreeViewDesignerPlugin::toolTip() const
{
        return "A tree view with more features";
}

QString SKGTreeViewDesignerPlugin::whatsThis() const
{
        return "A tree view with more features";
}

bool SKGTreeViewDesignerPlugin::isContainer() const
{
        return true;
}

QString SKGTreeViewDesignerPlugin::domXml() const
{
        return "<widget class=\"SKGTreeView\" name=\"SKGTreeView\">\n"
               " <property name=\"geometry\">\n"
               "  <rect>\n"
               "   <x>0</x>\n"
               "   <y>0</y>\n"
               "   <width>100</width>\n"
               "   <height>100</height>\n"
               "  </rect>\n"
               " </property>\n"
               "</widget>\n";
}

QString SKGTreeViewDesignerPlugin::includeFile() const
{
        return "skgtreeview.h";
}
